BACTERIA = "bacteria"
CRYPTOCOCCUS_NEOFORMANS = "cryptococcus_neoformans"
ECOLI = "e_coli"
HEADACHE = "headache"
KLEBSIELLA_SPP = "klebsiella_sp"
LAM_NEG0 = "0"
LAM_POS1 = "1"
LAM_POS2 = "2"
LAM_POS3 = "3"
LAM_POS4 = "4"
LAM_POS5 = "5"
NO_GROWTH = "no_growth"
TB_ACTION = "reportable-tb-result"
