# Generated by Django 3.2.11 on 2022-02-24 16:26

import edc_model.validators.date
import edc_protocol.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_microbiology", "0007_auto_20220224_1910"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_afb_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[
                    edc_protocol.validators.date_not_before_study_start,
                    edc_model.validators.date.date_not_future,
                ],
                verbose_name="Sputum AFB date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_afb_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Sputum AFB microscopy performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_afb_result",
            field=models.CharField(
                choices=[("POS", "Positive"), ("NEG", "Negative"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=10,
                verbose_name="Sputum AFB results",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_culture_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Sputum culture performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_culture_result",
            field=models.CharField(
                choices=[
                    ("POS", "MTB Positive"),
                    ("NEG", "MTB Negative"),
                    ("IND", "Indeterminate / contaminated"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Sputum culture results",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_genexpert_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[
                    edc_protocol.validators.date_not_before_study_start,
                    edc_model.validators.date.date_not_future,
                ],
                verbose_name="Sputum Gene-Xpert date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="sputum_genexpert_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Sputum Gene-Xpert performed?",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_afb_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[
                    edc_protocol.validators.date_not_before_study_start,
                    edc_model.validators.date.date_not_future,
                ],
                verbose_name="Sputum AFB date",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_afb_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Sputum AFB microscopy performed?",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_afb_result",
            field=models.CharField(
                choices=[("POS", "Positive"), ("NEG", "Negative"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=10,
                verbose_name="Sputum AFB results",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_culture_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Sputum culture performed?",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_culture_result",
            field=models.CharField(
                choices=[
                    ("POS", "MTB Positive"),
                    ("NEG", "MTB Negative"),
                    ("IND", "Indeterminate / contaminated"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Sputum culture results",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_genexpert_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[
                    edc_protocol.validators.date_not_before_study_start,
                    edc_model.validators.date.date_not_future,
                ],
                verbose_name="Sputum Gene-Xpert date",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="sputum_genexpert_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Sputum Gene-Xpert performed?",
            ),
        ),
    ]
